/// <reference types="react" />
import * as React from "react";
import { MarginClass, PaddingClass, BgColorClass, FgColorClass, VerticalAlignment, HorizontalAlignment } from "./../../utilities/uiHelpers";
export interface IGrid extends React.HTMLProps<HTMLDivElement> {
    /** (boolean) Wether to render borders around grid parts */
    debugMode?: boolean;
    /** (boolean) ADVANCED: Turns of automatic fix of safari6 compat wrapper */
    disableFlexOverride?: boolean;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
    /** (boolean) Render the first row to simulate a table header */
    table?: boolean;
    /** (boolean) Wether the table should expand and divide to fill its container */
    fillContainer?: boolean;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: keyof React.ReactHTML;
}
export declare class Grid extends React.Component<IGrid, {}> {
    render(): React.DetailedReactHTMLElement<{
        className: string;
    }, HTMLElement>;
    componentDidMount(): void;
}
export interface IRow extends React.HTMLProps<HTMLDivElement> {
    /** (number | string) Sets a fixed height for the row, or 'auto' to grow to fit its content */
    height?: number | string;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: string;
    /** (Col[]) A row must contain one or many <Col/> elements */
    children?: React.ReactNode;
}
export declare function Row(props: IRow): React.DOMElement<{
    className: string;
    style: React.CSSProperties;
    children?: React.ReactNode;
    accept?: string;
    acceptCharset?: string;
    action?: string;
    allowFullScreen?: boolean;
    allowTransparency?: boolean;
    alt?: string;
    as?: string;
    async?: boolean;
    autoComplete?: string;
    autoFocus?: boolean;
    autoPlay?: boolean;
    capture?: boolean;
    cellPadding?: string | number;
    cellSpacing?: string | number;
    charSet?: string;
    challenge?: string;
    checked?: boolean;
    cite?: string;
    classID?: string;
    cols?: number;
    colSpan?: number;
    content?: string;
    controls?: boolean;
    coords?: string;
    crossOrigin?: string;
    data?: string;
    dateTime?: string;
    default?: boolean;
    defer?: boolean;
    disabled?: boolean;
    download?: any;
    encType?: string;
    form?: string;
    formAction?: string;
    formEncType?: string;
    formMethod?: string;
    formNoValidate?: boolean;
    formTarget?: string;
    frameBorder?: string | number;
    headers?: string;
    high?: number;
    href?: string;
    hrefLang?: string;
    htmlFor?: string;
    httpEquiv?: string;
    integrity?: string;
    keyParams?: string;
    keyType?: string;
    kind?: string;
    label?: string;
    list?: string;
    loop?: boolean;
    low?: number;
    manifest?: string;
    marginHeight?: number;
    marginWidth?: number;
    max?: string | number;
    maxLength?: number;
    media?: string;
    mediaGroup?: string;
    method?: string;
    min?: string | number;
    minLength?: number;
    multiple?: boolean;
    muted?: boolean;
    name?: string;
    nonce?: string;
    noValidate?: boolean;
    open?: boolean;
    optimum?: number;
    pattern?: string;
    placeholder?: string;
    playsInline?: boolean;
    poster?: string;
    preload?: string;
    readOnly?: boolean;
    rel?: string;
    required?: boolean;
    reversed?: boolean;
    rows?: number;
    rowSpan?: number;
    sandbox?: string;
    scope?: string;
    scoped?: boolean;
    scrolling?: string;
    seamless?: boolean;
    selected?: boolean;
    shape?: string;
    size?: number;
    sizes?: string;
    span?: number;
    src?: string;
    srcDoc?: string;
    srcLang?: string;
    srcSet?: string;
    start?: number;
    step?: string | number;
    summary?: string;
    target?: string;
    type?: string;
    useMap?: string;
    value?: string | number | string[];
    width?: string | number;
    wmode?: string;
    wrap?: string;
    defaultChecked?: boolean;
    defaultValue?: string | string[];
    suppressContentEditableWarning?: boolean;
    accessKey?: string;
    contentEditable?: boolean;
    contextMenu?: string;
    dir?: string;
    draggable?: boolean;
    hidden?: boolean;
    id?: string;
    lang?: string;
    slot?: string;
    spellCheck?: boolean;
    tabIndex?: number;
    title?: string;
    inputMode?: string;
    is?: string;
    radioGroup?: string;
    role?: string;
    about?: string;
    datatype?: string;
    inlist?: any;
    prefix?: string;
    property?: string;
    resource?: string;
    typeof?: string;
    vocab?: string;
    autoCapitalize?: string;
    autoCorrect?: string;
    autoSave?: string;
    color?: string;
    itemProp?: string;
    itemScope?: boolean;
    itemType?: string;
    itemID?: string;
    itemRef?: string;
    results?: number;
    security?: string;
    unselectable?: boolean;
    dangerouslySetInnerHTML?: {
        __html: string;
    };
    onCopy?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCopyCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCut?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCutCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPaste?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPasteCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCompositionEnd?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionEndCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStart?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStartCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdate?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdateCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onFocusCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlur?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlurCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onChange?: (event: React.FormEvent<HTMLDivElement>) => void;
    onChangeCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInput?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInputCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onReset?: (event: React.FormEvent<HTMLDivElement>) => void;
    onResetCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmit?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmitCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalid?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalidCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onLoad?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onError?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onErrorCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onKeyDown?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyDownCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPress?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPressCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUp?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUpCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onAbort?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onAbortCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThrough?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThroughCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptied?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptiedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncrypted?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncryptedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEnded?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEndedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedData?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedDataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadata?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStart?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStartCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPause?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPauseCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlaying?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgress?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgressCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeked?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeking?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalled?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalledCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspend?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspendCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdate?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdateCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaiting?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaitingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenuCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDrag?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnd?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEndCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnter?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnterCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExit?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExitCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeave?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeaveCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOver?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOverCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStart?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStartCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDrop?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDropCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseDownCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMove?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMoveCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOut?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOutCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOver?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOverCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUp?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUpCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onSelect?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSelectCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTouchCancel?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchCancelCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEnd?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEndCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMove?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMoveCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStart?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStartCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onScroll?: (event: React.UIEvent<HTMLDivElement>) => void;
    onScrollCapture?: (event: React.UIEvent<HTMLDivElement>) => void;
    onWheel?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onWheelCapture?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onAnimationStart?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationStartCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEnd?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEndCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIteration?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIterationCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onTransitionEnd?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    onTransitionEndCapture?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    ref?: React.Ref<HTMLDivElement>;
    key?: string | number;
}, HTMLDivElement>;
export interface ICol extends React.HTMLProps<HTMLDivElement> {
    /** (HorizontalAlignment(string)) How to align content horizontally in this column */
    horizontalAlignment?: HorizontalAlignment;
    /** (HorizontalAlignment(string)) How to align content vertically in this column */
    verticalAlignment?: VerticalAlignment;
    /** (number | string) Sets a fixed width for the column, or 'auto' to grow to fit its content */
    width?: number | string;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: string;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
}
export declare function Col(props: ICol): React.DOMElement<{
    className: string;
    style: React.CSSProperties;
    accept?: string;
    acceptCharset?: string;
    action?: string;
    allowFullScreen?: boolean;
    allowTransparency?: boolean;
    alt?: string;
    as?: string;
    async?: boolean;
    autoComplete?: string;
    autoFocus?: boolean;
    autoPlay?: boolean;
    capture?: boolean;
    cellPadding?: string | number;
    cellSpacing?: string | number;
    charSet?: string;
    challenge?: string;
    checked?: boolean;
    cite?: string;
    classID?: string;
    cols?: number;
    colSpan?: number;
    content?: string;
    controls?: boolean;
    coords?: string;
    crossOrigin?: string;
    data?: string;
    dateTime?: string;
    default?: boolean;
    defer?: boolean;
    disabled?: boolean;
    download?: any;
    encType?: string;
    form?: string;
    formAction?: string;
    formEncType?: string;
    formMethod?: string;
    formNoValidate?: boolean;
    formTarget?: string;
    frameBorder?: string | number;
    headers?: string;
    height?: string | number;
    high?: number;
    href?: string;
    hrefLang?: string;
    htmlFor?: string;
    httpEquiv?: string;
    integrity?: string;
    keyParams?: string;
    keyType?: string;
    kind?: string;
    label?: string;
    list?: string;
    loop?: boolean;
    low?: number;
    manifest?: string;
    marginHeight?: number;
    marginWidth?: number;
    max?: string | number;
    maxLength?: number;
    media?: string;
    mediaGroup?: string;
    method?: string;
    min?: string | number;
    minLength?: number;
    multiple?: boolean;
    muted?: boolean;
    name?: string;
    nonce?: string;
    noValidate?: boolean;
    open?: boolean;
    optimum?: number;
    pattern?: string;
    placeholder?: string;
    playsInline?: boolean;
    poster?: string;
    preload?: string;
    readOnly?: boolean;
    rel?: string;
    required?: boolean;
    reversed?: boolean;
    rows?: number;
    rowSpan?: number;
    sandbox?: string;
    scope?: string;
    scoped?: boolean;
    scrolling?: string;
    seamless?: boolean;
    selected?: boolean;
    shape?: string;
    size?: number;
    sizes?: string;
    span?: number;
    src?: string;
    srcDoc?: string;
    srcLang?: string;
    srcSet?: string;
    start?: number;
    step?: string | number;
    summary?: string;
    target?: string;
    type?: string;
    useMap?: string;
    value?: string | number | string[];
    wmode?: string;
    wrap?: string;
    defaultChecked?: boolean;
    defaultValue?: string | string[];
    suppressContentEditableWarning?: boolean;
    accessKey?: string;
    contentEditable?: boolean;
    contextMenu?: string;
    dir?: string;
    draggable?: boolean;
    hidden?: boolean;
    id?: string;
    lang?: string;
    slot?: string;
    spellCheck?: boolean;
    tabIndex?: number;
    title?: string;
    inputMode?: string;
    is?: string;
    radioGroup?: string;
    role?: string;
    about?: string;
    datatype?: string;
    inlist?: any;
    prefix?: string;
    property?: string;
    resource?: string;
    typeof?: string;
    vocab?: string;
    autoCapitalize?: string;
    autoCorrect?: string;
    autoSave?: string;
    color?: string;
    itemProp?: string;
    itemScope?: boolean;
    itemType?: string;
    itemID?: string;
    itemRef?: string;
    results?: number;
    security?: string;
    unselectable?: boolean;
    children?: React.ReactNode;
    dangerouslySetInnerHTML?: {
        __html: string;
    };
    onCopy?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCopyCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCut?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCutCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPaste?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPasteCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCompositionEnd?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionEndCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStart?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStartCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdate?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdateCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onFocusCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlur?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlurCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onChange?: (event: React.FormEvent<HTMLDivElement>) => void;
    onChangeCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInput?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInputCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onReset?: (event: React.FormEvent<HTMLDivElement>) => void;
    onResetCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmit?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmitCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalid?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalidCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onLoad?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onError?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onErrorCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onKeyDown?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyDownCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPress?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPressCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUp?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUpCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onAbort?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onAbortCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThrough?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThroughCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptied?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptiedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncrypted?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncryptedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEnded?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEndedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedData?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedDataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadata?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStart?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStartCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPause?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPauseCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlaying?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgress?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgressCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeked?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeking?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalled?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalledCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspend?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspendCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdate?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdateCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaiting?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaitingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenuCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDrag?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnd?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEndCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnter?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnterCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExit?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExitCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeave?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeaveCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOver?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOverCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStart?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStartCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDrop?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDropCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseDownCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMove?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMoveCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOut?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOutCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOver?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOverCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUp?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUpCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onSelect?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSelectCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTouchCancel?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchCancelCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEnd?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEndCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMove?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMoveCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStart?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStartCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onScroll?: (event: React.UIEvent<HTMLDivElement>) => void;
    onScrollCapture?: (event: React.UIEvent<HTMLDivElement>) => void;
    onWheel?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onWheelCapture?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onAnimationStart?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationStartCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEnd?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEndCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIteration?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIterationCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onTransitionEnd?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    onTransitionEndCapture?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    ref?: React.Ref<HTMLDivElement>;
    key?: string | number;
}, HTMLDivElement>;
